@@ -50,11 +50,11 @@ def run(app_file: str, app='fastapi', port=9955, nohup=0):
 
 # 一键起服务
 @cli.command()
-def easy_run(app_dir: str, port=8000, access_log=True, prefix='/'):
+def easy_run(app_dir: str, port=8000, access_log=True):
     from appzoo import App
 
     app = App()
-    app.add_apps(app_dir, prefix=prefix)
+    app.add_apps(app_dir)
     app.run(port=port, access_log=access_log)
 
 
